pub trait InteractionSession: Send + Sync {
// Required methods
fn prepare<'life0, 'life1, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request: InteractionRequest,
) -> Pin<Box<dyn Future<Output = Result<(), PortFailure>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn wait<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<InteractionResponse, PortFailure>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
// Provided method
fn request<'life0, 'life1, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request: InteractionRequest,
) -> Pin<Box<dyn Future<Output = Result<InteractionResponse, PortFailure>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
}Required Methods
Sourcefn prepare<'life0, 'life1, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request: InteractionRequest,
) -> Pin<Box<dyn Future<Output = Result<(), PortFailure>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn prepare<'life0, 'life1, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request: InteractionRequest,
) -> Pin<Box<dyn Future<Output = Result<(), PortFailure>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Register a pending request before it becomes externally visible.
Sourcefn wait<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<InteractionResponse, PortFailure>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn wait<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<InteractionResponse, PortFailure>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Wait for a response to a request registered by Self::prepare.
Provided Methods
fn request<'life0, 'life1, 'async_trait>(
&'life0 self,
operation: &'life1 OperationContext,
request: InteractionRequest,
) -> Pin<Box<dyn Future<Output = Result<InteractionResponse, PortFailure>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".